@@ -8,13 +8,7 @@ from requests.adapters import HTTPAdapter
 from tqdm import tqdm
 from tqdm.utils import CallbackIOWrapper
 
-from rime_sdk.internal.grpc_error_handler import GRPCErrorHandler
-from rime_sdk.protos.file_upload.file_upload_pb2 import (
-    GetDatasetFileUploadURLRequest,
-    GetModelDirectoryUploadURLsRequest,
-    ListUploadedFileURLsRequest,
-)
-from rime_sdk.protos.file_upload.file_upload_pb2_grpc import FileUploadStub
+from rime_sdk.swagger.swagger_client import ApiClient, FileUploadApi
 
 
 def _now_str() -> str:
@@ -38,9 +32,10 @@ def _get_files_to_upload(dir_path: Path, upload_hidden: bool) -> Iterator[Path]:
 class FileUploadModule:
     """A module that implements file uploading using a FileUploadStub."""
 
-    def __init__(self, file_upload_client: FileUploadStub):
+    def __init__(self, api_client: ApiClient):
         """Create a FileUploadModule for the `file_upload_client`."""
-        self._file_upload_client = file_upload_client
+        self._api_client = api_client
+        self._file_upload_client = FileUploadApi(self._api_client)
 
     def upload_dataset_file(
         self, file_path: Path, upload_path: Optional[str] = None,
@@ -54,7 +49,7 @@ class FileUploadModule:
                 Path to the file to be uploaded to RIME's blob store.
             upload_path: Optional[str] = None
                 Name of the directory in the blob store file system. If omitted,
-                a unique random string will be the direcory.
+                a unique random string will be the directory.
 
         Returns:
             A reference to the uploaded file's location in the blob store. This
@@ -77,12 +72,15 @@ class FileUploadModule:
         file_size = file_path.stat().st_size
 
         file_name = file_path.name
-        req = GetDatasetFileUploadURLRequest(file_name=file_name)
         if upload_path is not None:
-            req.upload_path = upload_path
-        with GRPCErrorHandler():
-            resp = self._file_upload_client.GetDatasetFileUploadURL(request=req)
-            self._impose_size_constraint(file_size, resp.upload_limit)
+            resp = self._file_upload_client.file_upload_get_dataset_file_upload_url(
+                file_name=file_name, upload_path=upload_path
+            )
+        else:
+            resp = self._file_upload_client.file_upload_get_dataset_file_upload_url(
+                file_name=file_name,
+            )
+        self._impose_size_constraint(file_size, int(resp.upload_limit))
         self._upload_object(file_path, resp.upload_url)
         self._upload_string(f"Upload complete: {_now_str()}", resp.done_file_upload_url)
         return resp.destination_url
@@ -108,7 +106,7 @@ class FileUploadModule:
                 (ie. those beginning with a '.').
             upload_path: Optional[str] = None
                 Name of the directory in the blob store file system. If omitted,
-                a unique random string will be the direcory.
+                a unique random string will be the directory.
 
         Returns:
             A reference to the uploaded directory's location in the blob store. This
@@ -136,14 +134,17 @@ class FileUploadModule:
                 rel_paths.append(str(file_path.relative_to(dir_path)))
         if len(rel_paths) == 0:
             raise IOError(f"directory '{dir_path}' is empty")
-        req = GetModelDirectoryUploadURLsRequest(
-            directory_name=dir_path.name, relative_file_paths=rel_paths,
-        )
         if upload_path is not None:
-            req.upload_path = upload_path
-        with GRPCErrorHandler():
-            resp = self._file_upload_client.GetModelDirectoryUploadURLs(request=req)
-            self._impose_size_constraint(total_size, resp.upload_limit)
+            resp = self._file_upload_client.file_upload_get_model_directory_upload_urls(  # noqa: E501
+                directory_name=dir_path.name,
+                relative_file_paths=rel_paths,
+                upload_path=upload_path,
+            )
+        else:
+            resp = self._file_upload_client.file_upload_get_model_directory_upload_urls(  # noqa: E501
+                directory_name=dir_path.name, relative_file_paths=rel_paths
+            )
+        self._impose_size_constraint(total_size, int(resp.upload_limit))
         for rel_path in resp.upload_path_map:
             file_path = dir_path / rel_path
             self._upload_object(file_path, resp.upload_path_map[rel_path])
@@ -152,9 +153,7 @@ class FileUploadModule:
 
     def list_uploaded_files_urls(self) -> Iterator[str]:
         """Return an iterator of file paths that have been uploaded."""
-        req = ListUploadedFileURLsRequest()
-        with GRPCErrorHandler():
-            resp = self._file_upload_client.ListUploadedFileURLs(request=req)
+        resp = self._file_upload_client.file_upload_list_uploaded_file_urls()
         return resp.file_urls
 
     def _upload_object(self, file_path: Path, upload_url: str) -> None:
@@ -168,8 +167,14 @@ class FileUploadModule:
                 unit_divisor=1024,
                 desc=f"Uploading {file_path}",
             ) as t:
-                wrapped_file = CallbackIOWrapper(t.update, f, "read")
-                http_response = session.put(url=upload_url, data=wrapped_file)
+                if file_size == 0:
+                    # If the file is 0 bytes, using the TQDM io wrapper does not
+                    # work, so we simply write an empty file directly.
+                    http_response = session.put(url=upload_url, data="")
+                    t.close()
+                else:
+                    wrapped_file = CallbackIOWrapper(t.update, f, "read")
+                    http_response = session.put(url=upload_url, data=wrapped_file)
                 if http_response.status_code != 200:
                     raise ValueError(
                         f"upload of '{file_path}' failed with "
