@@ -9,13 +9,22 @@ from rime_sdk.internal.config_parser import convert_config_to_swagger
 from rime_sdk.internal.rest_error_handler import RESTErrorHandler
 from rime_sdk.internal.swagger_utils import (
     get_bin_size_swagger,
+    get_data_params_swagger,
     get_data_type_enum_swagger,
+    get_model_task_enum_swagger,
+    get_swagger_data_type_enum,
     get_threshold_info_swagger,
     location_args_to_data_location_swagger,
+    valid_model_task_for_data_type,
 )
 from rime_sdk.internal.utils import convert_dict_to_html, make_link
+from rime_sdk.job import Job
 from rime_sdk.swagger import swagger_client
-from rime_sdk.swagger.swagger_client import ApiClient
+from rime_sdk.swagger.swagger_client import (
+    ApiClient,
+    RimeCreateFirewallFromDataRequest,
+    RimeDataLocation,
+)
 from rime_sdk.swagger.swagger_client.models import (
     ComponentsProjectIdBody,
     DigestConfigDigestFrequency,
@@ -463,6 +472,105 @@ class Project:
             res = cast(RimeCreateFirewallResponse, res)
             return Firewall(self._api_client, res.firewall_id)
 
+    def create_firewall_from_data(
+        self,
+        name: str,
+        data_type: str,
+        model_task: str,
+        bin_size: str,
+        data_params: Dict,
+        rolling_window_duration: Optional[timedelta] = None,
+        reference_set_time_bin: Optional[Tuple[datetime, datetime]] = None,
+        reference_set_file_path: Optional[str] = None,
+        run_ct_schedule: bool = False,
+        location_type: Optional[str] = None,
+        location_info: Optional[dict] = None,
+    ) -> Tuple[Job, str]:
+        """Create a firewall directly from data without a stress test.
+
+        Arguments:
+            name: str
+                FW name.
+            data_type: str
+                Data type. Can be `tabular` or `nlp`.
+            model_task: str
+                Model task. Can be `Binary Classification`, `Multi-class
+                Classification`, `Regression`, `Ranking`, `Named Entity Recognition`,
+                `Natural Language Inference`, or `Text Classification`.
+            bin_size: str
+                Bin size. Can be `year`, `month`, `week`, `day`, `hour`.
+            data_params: Dict
+                Information needed to process data from the data location provided.
+                By default, these are obtained from your reference information.
+                Eg. `pred_col`, `timestamp_col`, `label_col`, etc...
+            rolling_window_duration: Optional[timedelta]
+                Fixed Time duration of rolling window.
+                Only one of rolling_window_seconds, reference_set_time_bin, or
+                reference_set_file_path may be set. If this is specified, then data
+                location and its related parameters must be set.
+            reference_set_time_bin: Optional[Tuple[datetime, datetime]]
+                Time bin of reference set can be set for firewall running scheduled ct.
+                Only one of rolling_window_seconds, reference_set_time_bin, or
+                reference_set_file_path may be set. If this is specified, then data
+                location and its related parameters must be set.
+            reference_set_file_path: str
+                File path for reference set in S3 bucket.
+                Only one of rolling_window_seconds, reference_set_time_bin, or
+                reference_set_file_path may be set.
+            run_ct_schedule: bool
+                Flag for ct scheduler.
+            location_type: Optional[str]
+                Type of the data location that ScheduledCT will pull data from.
+            location_info: Optional[Dict]
+                Information needed to access the data location provided.
+
+        Returns:
+            A tuple containing the job for profiling the reference set and the
+            firewall ID.
+
+        Raises:
+            ValueError
+                If the provided values are invalid.
+        """
+        data_type_sw = get_swagger_data_type_enum(data_type)
+        model_task_sw = get_model_task_enum_swagger(model_task)
+        if not valid_model_task_for_data_type(model_task_sw, data_type_sw):
+            raise ValueError(f"Model task {model_task} not valid for {data_type} data.")
+        if reference_set_file_path is None and location_type is None:
+            raise ValueError("Data location required if no file path specified.")
+
+        data_location_sw: Optional[RimeDataLocation] = None
+        if location_type is not None:
+            data_location_sw = location_args_to_data_location_swagger(
+                location_type=location_type,
+                location_info=location_info,
+                data_params=data_params,
+                data_type=data_type_sw,
+            )
+
+        data_params_sw = get_data_params_swagger(data_params, data_type_sw)
+        req = RimeCreateFirewallFromDataRequest(
+            name=name,
+            project_id=self._project_id,
+            data_type=data_type_sw,
+            model_task=model_task_sw,
+            run_ct_schedule=run_ct_schedule,
+            bin_size=get_bin_size_swagger(bin_size),
+            reference_set_source=get_reference_set_source(
+                reference_set_time_bin=reference_set_time_bin,
+                rolling_window_duration=rolling_window_duration,
+                file_path=reference_set_file_path,
+            ),
+            data_location_info=data_location_sw,
+            data_params=data_params_sw,
+        )
+        with RESTErrorHandler():
+            api = swagger_client.ModelTestingApi(self._api_client)
+            response = api.model_testing_create_firewall_from_data(body=req)
+            job = Job(self._api_client, response.stress_test_job.job_id)
+            firewall_id = response.firewall.id
+        return job, firewall_id
+
     def _get_firewall_id(self) -> Optional[str]:
         api = swagger_client.ProjectManagerApi(self._api_client)
         with RESTErrorHandler():
